Package: knotR
Type: Package
Title: Knot Diagrams using Bezier Curves
Version: 1.0-4
Authors@R: person(given=c("Robin", "K. S."), family="Hankin", role = c("aut","cre"), email="hankin.robin@gmail.com", comment = c(ORCID = "0000-0001-5982-0415"))
Depends: R (>= 2.10)
Maintainer: Robin K. S. Hankin <hankin.robin@gmail.com>
LazyData: TRUE
Description: Makes visually pleasing diagrams of knot projections using optimized Bezier curves.
License: GPL-2
NeedsCompilation: no
Packaged: 2024-01-22 19:56:20 UTC; rhankin
Author: Robin K. S. Hankin [aut, cre] (<https://orcid.org/0000-0001-5982-0415>)
Repository: CRAN
Date/Publication: 2024-01-24 08:50:02 UTC
Built: R 4.3.3; ; 2025-01-24 09:01:20 UTC; unix
